<?php

App::uses('EvLocationAppController', 'EvLocation.Controller');

class LocationsController extends EvLocationAppController {


	public function beforeFilter() {

		parent::beforeFilter();

		$this->Auth->allow(array(
			'index',
			'view',
			'multipoint'
		));

	}


	protected function _adminFormFields() {

		// Model instance
		$Model = $this->{$this->modelClass};

		$fields = parent::_adminFormFields();

		// remove all fields related to the Location model that are
		// not defined in the plugin config file
		$requiredFields = Configure::read('EvLocation.fields');

		if (isset($requiredFields) && !empty($requiredFields)) {

			foreach ($fields as $key => $value) {
				if (
					preg_match("/{$Model->alias}/", $key)
					&& !in_array(str_replace('Location.', '', $key), $requiredFields)
				) {
					unset($fields[$key]);
				}
			}

		}

		return $fields;
	}


/**
 * Index
 *
 * Returns locations listing, based on type defined in config
 */
	public function index() {

		// Model instance
		$Model = $this->{$this->modelClass};

		// if set then find and assign page data
		$pageId = Configure::read('EvLocation.pageId');

		if (isset($pageId) && !empty($pageId)) {

			ClassRegistry::init('Page');
			$Page = new Page();

			$pageData = $Page->readForView($pageId);
			$this->set('page', $pageData);

			// assign page meta data
			$this->Meta->set($pageData);
		}

		// find and assign listing of locations
		$params = array(
			'contain' => array(
				'Image'
			)
		);

		$this->set('listing', $Model->all($params));

		$viewType = Configure::read('EvLocation.type');

		if (isset($viewType) && $viewType == 'multipoint') {

			$this->view = 'EvLocation.multipoint';
		} else {

			$this->view = 'EvLocation.index';
		}

	}


/**
 * View
 *
 * Returns the requested location
 */
	public function view($id = null) {

		// Model instance
		$Model = $this->{$this->modelClass};

		// find and assign listing of location
		$params = array(
			'conditions' => array(
				'Location.is_active' => true,
			),
			'contain' => array(
				'Image'
			),
		);

		// determine whether we are showing a specific location
		if ($id) {
			$params['conditions']['Location.id'] = $id;
		} else {
			$params['order']['Location.lft'] = 'asc';
		}

		$data = $Model->readForView($id, $params);

		if (!isset($data) || empty($data)) {
			throw new NotFoundException();
		}

		$this->set('data', $data);

		// assign page meta data
		$this->Meta->set($data);

		$this->view = 'EvLocation.view';
	}
}